Università di Padova
Author: H-art 2011
Description: UniPD

#

Ricerca Cerca

X

Mostra tutti >

Vai al contenuto

## Notizie

- ### Percorsi di teatro e altri linguaggi
  Incontro al Bo con Michele Sambin Vai alla news

- ### Scuola
  Sogni (e incubi) della riforma Vai alla news

- ### Concerti, danza e teatro
  RadioBue.it regala i biglietti Vai alla news

- ### Primo appuntamento per "La scienza in Orto"
  Attività e conferenze all'Orto botanico
  13 e 14 dicembre Vai alla news

- ## International area

  Enjoying the World

- ## IN PRIMO PIANO

  ### Erasmus Mundus
  le scadenze

  Borse di studio per il 2014/15 e 2015/16

- ## EVENTI

  11 dicembre 2014

  ### La corruzione a due anni dalla "Riforma Severino"

  Convegno di studi

- ### Vedi tutti gli eventi

### Amministrazione trasparente

### Albo ufficiale

- YouTube
- facebook
- iTunes U
- Radio Bue